import * as cdk from "@aws-cdk/core";
import { Construct } from "@aws-cdk/core";
import { NotificationType } from "./NotificationType";
import { TimeUnit } from "./TimeUnit";
/**
 * (experimental) Configuration options of the {@link BudgetNotifier | BudgetNotifier}.
 *
 * @experimental
 */
export interface BudgetNotifierProps {
    /**
     * (experimental) Budget notifications will be sent to each of the recipients (e-mail addresses).
     *
     * A maximum of 10 recipients is allowed.
     *
     * @experimental
     */
    readonly recipients?: Array<string>;
    /**
     * @experimental
     */
    readonly topicArn?: string;
    /**
     * (experimental) If specified the availability zones will be added as tag filter.
     *
     * @experimental
     */
    readonly availabilityZones?: Array<string>;
    /**
     * (experimental) If specified the application name will be added as tag filter.
     *
     * @experimental
     */
    readonly application?: string;
    /**
     * (experimental) If specified the cost center will be added as tag filter.
     *
     * @experimental
     */
    readonly costCenter?: string;
    /**
     * (experimental) If specified the service will be added as tag filter.
     *
     * @experimental
     */
    readonly service?: string;
    /**
     * (experimental) The threshold value in percent (0-100).
     *
     * @experimental
     */
    readonly threshold: number;
    /**
     * (experimental) The length of time until a budget resets the actual and forecasted spend.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-budgetdata.html#cfn-budgets-budget-budgetdata-timeunit
     * @experimental
     */
    readonly timeUnit?: TimeUnit;
    /**
     * (experimental) The cost associated with the budget threshold.
     *
     * @experimental
     */
    readonly limit: number;
    /**
     * (experimental) The unit of measurement that is used for the budget threshold, such as dollars or GB.
     *
     * @experimental
     */
    readonly unit: string;
    /**
     * (experimental) Whether the notification is for how much you have spent (ACTUAL) or for how much you're forecasted to spend (FORECASTED).
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-notification.html#cfn-budgets-budget-notification-notificationtype
     * @experimental
     */
    readonly notificationType?: NotificationType;
}
/**
 * @experimental
 */
export declare class BudgetNotifier extends Construct {
    /**
     * @experimental
     */
    constructor(scope: cdk.Construct, id: string, props: BudgetNotifierProps);
    private validateProperties;
    private createSubscribers;
    private createCostFilters;
}
